@@ -34,7 +34,8 @@ from blessings import Terminal
 from nose import SkipTest
 from nose.tools import eq_, ok_
 
-from traceback import format_traceback, human_path, source_path, format_list, extract_tb, print_tb, print_exception
+from traceback import (format_traceback, human_path, source_path, format_list,
+                       extract_tb, print_tb, print_exception, print_list)
 
 
 syntax_error_tb = ([
@@ -71,7 +72,8 @@ def test_source_path():
 def test_syntax_error():
     """Special handling of syntax errors should format nicely and not crash."""
     raise SkipTest
-    f = ''.join(format_traceback(*syntax_error_tb, term=Terminal(stream=StringIO())))
+    options = dict(term=Terminal(stream=StringIO()))
+    f = ''.join(format_traceback(*syntax_error_tb, **options))
     assert f.endswith(
         """vi +97  /Users/erose/Checkouts/nose-progress/noseprogressive/tests/test_integration.py
     :bad
@@ -83,7 +85,8 @@ SyntaxError: invalid syntax
 def test_non_syntax_error():
     """Typical error formatting should work and relativize paths."""
     raise SkipTest
-    f = ''.join(format_traceback(*attr_error_tb, term=Terminal(stream=StringIO())))
+    options = dict(term=Terminal(stream=StringIO()))
+    f = ''.join(format_traceback(*attr_error_tb, **options))
     print f
     print repr(f)
     eq_(f, """  vi +2926 /usr/share/PackageKit/helpers/yum/yumBackend.py  # install_signature
@@ -126,19 +129,26 @@ def test_unicode():
 
 
 def test_format_list():
-    eq_(format_list(extract_tb(_tb())), [u'  \x1b[90m\x1b[1mbbedit +21 tests.py\x1b(B\x1b[m\x1b[94m  # _triple\x1b(B\x1b[m\n    one()\n', u'  \x1b[90m\x1b[1mbbedit +11 tests.py\x1b(B\x1b[m\x1b[94m  # one\x1b(B\x1b[m\n    two()\n', u'  \x1b[90m\x1b[1mbbedit +10 tests.py\x1b(B\x1b[m\x1b[94m  # two\x1b(B\x1b[m\n    h[1]\n'])
+    eq_(format_list(extract_tb(_tb())), [u'  \x1b[90m\x1b[1mbbedit +21 traceback/tests.py\x1b(B\x1b[m\x1b[94m  # _triple\x1b(B\x1b[m\n    one()\n', u'  \x1b[90m\x1b[1mbbedit +11 traceback/tests.py\x1b(B\x1b[m\x1b[94m  # one\x1b(B\x1b[m\n    two()\n', u'  \x1b[90m\x1b[1mbbedit +10 traceback/tests.py\x1b(B\x1b[m\x1b[94m  # two\x1b(B\x1b[m\n    h[1]\n'])
 
 
 def test_print_tb():
     out = StringIO()
     print_tb(_tb(), file=out)
-    eq_(out.getvalue(), u'  bbedit +21 tests.py  # _triple\n    one()\n  bbedit +11 tests.py  # one\n    two()\n  bbedit +10 tests.py  # two\n    h[1]\n')
+    eq_(out.getvalue(), u'  bbedit +21 traceback/tests.py  # _triple\n    one()\n  bbedit +11 traceback/tests.py  # one\n    two()\n  bbedit +10 traceback/tests.py  # two\n    h[1]\n')
+
+
+def test_print_list():
+    out = StringIO()
+    print_list(extract_tb(_tb()), file=out)
+    eq_(out.getvalue(), u'  bbedit +21 traceback/tests.py  # _triple\n    one()\n  bbedit +11 traceback/tests.py  # one\n    two()\n  bbedit +10 traceback/tests.py  # two\n    h[1]\n')
 
 
 def test_rebinding():
     """Make sure our new print_tb gets called by the routines we didn't patch."""
     out = StringIO()
-    print_exception(*_triple(), file=out)
+    options = dict(file=out)
+    print_exception(*_triple(), **options)
     value = out.getvalue()
     # Make sure the old formatting isn't happening:
     ok_('File "' not in value)
